from pathlib import Path


# Make arguments readable to other components
def expandargs(args):
    if args.MAPFILE is not None:
        args.MAPFILE = str(Path(args.MAPFILE).expanduser().resolve())
    if args.tileset is not None:
        args.tileset = str(Path(args.tileset).expanduser().resolve())
    if args.output is not None:
        args.output = str(Path(args.output).expanduser().resolve())

    return args



import sys
import argparse
import time
from pathlib import Path

sys.path.insert(0, str(Path(__file__).parent.resolve()))
import menu
import themes
import txtmap
import imgmap
import stretch


# Handle arguments
def getArgs(showHelp=0):
    parser = argparse.ArgumentParser(
        prog="donjon-painter",
        description="A tool to create dungeon maps from TSV files \
        (Donjon's Random Dungeon Generator)"
    )
    parser.add_argument(
        "MAPFILE", help="specify TSV file to parse", nargs='?')
    parser.add_argument(
        "-t", "--tileset",
        help="select the tileset folder to use (interactive mode if not)")
    parser.add_argument(
        "-m", "--measure",
        help="get the time it takes to execute the script",
        action="store_true")
    parser.add_argument(
        "-o", "--output",
        help="declare name and/or location of map to save",
        default=str(Path(Path.home(), 'Map.png')))
    parser.add_argument(
        "-p", "--pixels",
        help="specify the size of your map tile assets (default 70)",
        type=int,
        default=70)
    parser.add_argument(
        "-r", "--randomise",
        help="rotate the floor tile asset for some variation to the map",
        action="store_true")
    parser.add_argument(
        "-s", "--savetiles",
        help="generate a theme from a partial one (good for making themes)",
        action="store_true")

    if not showHelp:
        return parser.parse_args()
    else:
        return parser.print_help()


def main(args=None):
    if args is None:
        args = sys.argv[1:]

    args = getArgs()
    args = stretch.expandargs(args)

    # Execution Redux (Interactive Mode vs. Single Command Mode)
    if args.MAPFILE is None:
        menu.mainmenu(args)
    else:
        if args.tileset is None:
            themes.printThemes()
            args.tileset = themes.selTheme(args.tileset)
        if args.savetiles:
            start = time.time()

            tmpRes = themes.canGenerate(args.tileset, True)
            tmpRes = themes.generateTheme(tmpRes)
            if themes.writeTheme(args.tileset, tmpRes) is False:
                print("Theme cannot be saved - insufficient resources.")
            else:
                if args.measure:
                    end = time.time()
                    print("Theme generation done in", end - start, "seconds.")
        if args.measure:
            start = time.time()

        print("Attempting map generation...")

        tmpTheme = themes.canGenerate(args.tileset, True)
        tmpTheme = themes.generateTheme(tmpTheme)

        tmpMap = txtmap.readMap(args.MAPFILE)
        tmpMap = txtmap.parseMap(tmpMap)
        tmpMap = imgmap.generateMap(args, tmpTheme, tmpMap)

        if imgmap.writeMap(args, tmpMap) is False:
            print("Map cannot be saved - insufficient resources.")
        else:
            if args.measure:
                end = time.time()
                print("Map generation done in", end - start, "seconds.")
            print("Finished!")


if __name__ == "__main__":
    main()



import csv
from pathlib import Path


# Creates a 2D list from a TSV file
def readMap(mapfile):
    tmpArray = []
    if Path(mapfile).suffix != '.txt':
        mapfile = mapfile + '.txt'
    if Path(mapfile).is_file():
        with open(mapfile) as fd:
            rd = csv.reader(fd, delimiter="\t")
            for row in rd:
                tmpArray.append(row)
    return tmpArray

# Translating TSV map -> image map:
#   Link symbols to a list of nested dictionary key/values
#   E.g. [[tileCategory, tileType], [tileCategory, tileType]]


# Return a readable list of tile references from a 2D array
def parseMap(arrMap):
    # Symbols that need more parsing (multiple outcomes)
    nameList = {
        'S':        ['spaceAssets', 'dungeonSpace'],
        'WT':       ['wallAssets', 'wallTop'],
        'WB':       ['wallAssets', 'wallBottom'],
        'WL':       ['wallAssets', 'wallLeft'],
        'WR':       ['wallAssets', 'wallRight'],
        'ITL':      ['inCorners', 'topLeftCornerI'],
        'IBR':      ['inCorners', 'bottomRightCornerI'],
        'IBL':      ['inCorners', 'bottomLeftCornerI'],
        'ITR':      ['inCorners', 'topRightCornerI'],
        'OTL':      ['outCorners', 'topLeftCornerO'],
        'OBR':      ['outCorners', 'bottomRightCornerO'],
        'OBL':      ['outCorners', 'bottomLeftCornerO'],
        'OTR':      ['outCorners', 'topRightCornerO'],
        'SUT':      ['stairUAssets', 'topStairU'],
        'SUB':      ['stairUAssets', 'bottomStairU'],
        'SUL':      ['stairUAssets', 'leftStairU'],
        'SUR':      ['stairUAssets', 'rightStairU'],
        'SUUT':     ['stairUUAssets', 'topStairUU'],
        'SUUB':     ['stairUUAssets', 'bottomStairUU'],
        'SUUL':     ['stairUUAssets', 'leftStairUU'],
        'SUUR':     ['stairUUAssets', 'rightStairUU'],
        'SDT':      ['stairDAssets', 'topStairD'],
        'SDB':      ['stairDAssets', 'bottomStairD'],
        'SDL':      ['stairDAssets', 'leftStairD'],
        'SDR':      ['stairDAssets', 'rightStairD'],
        'SDDT':     ['stairDDAssets', 'topStairDD'],
        'SDDB':     ['stairDDAssets', 'bottomStairDD'],
        'SDDL':     ['stairDDAssets', 'leftStairDD'],
        'SDDR':     ['stairDDAssets', 'rightStairDD']
    }

    # One to one symbols (no function needed)
    txtSymbols = {
        'F':    [['floorAssets', 'floor']],
        'DT':   [['floorAssets', 'floor'],
                 ['doorAssets', 'doorTop']],
        'DB':   [['floorAssets', 'floor'],
                 ['doorAssets', 'doorBottom']],
        'DL':   [['floorAssets', 'floor'],
                 ['doorAssets', 'doorLeft']],
        'DR':   [['floorAssets', 'floor'],
                 ['doorAssets', 'doorRight']],
        'DST':  [['floorAssets', 'floor'],
                 ['doorSAssets', 'doorSecretTop']],
        'DSB':  [['floorAssets', 'floor'],
                 ['doorSAssets', 'doorSecretBottom']],
        'DSL':  [['floorAssets', 'floor'],
                 ['doorSAssets', 'doorSecretLeft']],
        'DSR':  [['floorAssets', 'floor'],
                 ['doorSAssets', 'doorSecretRight']],
        'DPT':  [['floorAssets', 'floor'],
                 ['doorPAssets', 'doorPortTop']],
        'DPB':  [['floorAssets', 'floor'],
                 ['doorPAssets', 'doorPortBottom']],
        'DPL':  [['floorAssets', 'floor'],
                 ['doorPAssets', 'doorPortLeft']],
        'DPR':  [['floorAssets', 'floor'],
                 ['doorPAssets', 'doorPortRight']]
    }

    # Return dictionary of items + adjacent letters (mapfile, position)
    def getCoordinates(m, y, x):
        maxY = len(m) - 1
        maxX = len(m[y]) - 1

        minimap = {
            'NW':   '_',   'N': '_',      'NE': '_',
            'W':    '_',   'M': m[y][x],   'E': '_',
            'SW':   '_',   'S': '_',      'SE': '_'
        }

        def setCardinal(mapfile, coord, pos, cond, yAdj, xAdj):
            if pos != cond:
                mapfile[coord] = m[y + yAdj][x + xAdj]
            return mapfile

        def setInterCard(mapfile, coord, pos, cond1, cond2, yAdj, xAdj):
            if pos[0] != cond1 and pos[1] != cond2:
                mapfile[coord] = m[y + yAdj][x + xAdj]
            return mapfile

        minimap = setCardinal(minimap, 'N', y, 0, -1, 0)
        minimap = setCardinal(minimap, 'E', x, maxX, 0, 1)
        minimap = setCardinal(minimap, 'S', y, maxY, 1, 0)
        minimap = setCardinal(minimap, 'W', x, 0, 0, -1)
        minimap = setInterCard(minimap, 'NE', (y, x), 0, maxX, -1, 1)
        minimap = setInterCard(minimap, 'SE', (y, x), maxY, maxX, 1, 1)
        minimap = setInterCard(minimap, 'SW', (y, x), maxY, 0, 1, -1)
        minimap = setInterCard(minimap, 'NW', (y, x), 0, 0, -1, -1)

        return minimap

    # Wall/space tiles needed
    def getWall(mapfile, yPos, xPos):
        mapPart = getCoordinates(mapfile, yPos, xPos)
        edges = [mapPart['N'], mapPart['S'], mapPart['W'], mapPart['E']]
        corners = [[mapPart['NE'], mapPart['N'], mapPart['E']],
                   [mapPart['SE'], mapPart['S'], mapPart['E']],
                   [mapPart['SW'], mapPart['S'], mapPart['W']],
                   [mapPart['NW'], mapPart['N'], mapPart['W']]]
        space = [mapPart['NW'], mapPart['N'],   mapPart['NE'],
                 mapPart['W'],  mapPart['M'],   mapPart['E'],
                 mapPart['SW'], mapPart['S'],   mapPart['SE']]

        wallArray = []

        # Tile logic (treat other tiles as 'floor')
        for key, items in enumerate(edges):
            if items != '':
                if (items[0] == 'D' or items[0] == 'S') and items != '_':
                    edges[key] = 'F'
        for supKey, items in enumerate(corners):
            for key, part in enumerate(items):
                if part != '':
                    if (part[0] == 'D' or part[0] == 'S') and part != '_':
                        corners[supKey][key] = 'F'
        for key, items in enumerate(space):
            if items == '_':
                space[key] = ''
        # Empty space if everything blank
        if space == ['', '', '', '', '', '', '', '', '']:
            wallArray.append(nameList['S'])

        # Straight walls
        wallType = ['WT', 'WB', 'WL', 'WR']
        for i, edge in enumerate(edges):
            if edge == 'F':
                wallArray.append(nameList[wallType[i]])

        # Inwards corner walls
        cornerTypeI = ['ITR', 'IBR', 'IBL', 'ITL']
        for i, corner in enumerate(corners):
            if corner == ['F', 'F', 'F']:
                wallArray.append(nameList[cornerTypeI[i]])

        # Outwards corner walls
        cornerTypeO = ['OTR', 'OBR', 'OBL', 'OTL']
        for i, corner in enumerate(corners):
            if corner == ['F', '', '']:
                wallArray.append(nameList[cornerTypeO[i]])

        return wallArray

    # Stair tiles needed
    def getStair(loc, stairType, stairKey):
        stairArray = []
        stairArray.append(txtSymbols['F'][0])

        for i, loc in enumerate(loc):
            if loc == stairKey:
                stairArray.append(nameList[stairType[i]])
        return stairArray

    def getUStair(mapfile, yPos, xPos):
        mapPart = getCoordinates(mapfile, yPos, xPos)
        stairs = [mapPart['N'], mapPart['E'], mapPart['S'], mapPart['W']]
        stairType = ['SUB', 'SUL', 'SUT', 'SUR']

        return getStair(stairs, stairType, 'SUU')

    def getUUStair(mapfile, yPos, xPos):
        mapPart = getCoordinates(mapfile, yPos, xPos)
        stairs = [mapPart['N'], mapPart['E'], mapPart['S'], mapPart['W']]
        stairType = ['SUUT', 'SUUR', 'SUUB', 'SUUL']

        return getStair(stairs, stairType, 'SU')

    def getDStair(mapfile, yPos, xPos):
        mapPart = getCoordinates(mapfile, yPos, xPos)
        stairs = [mapPart['N'], mapPart['E'], mapPart['S'], mapPart['W']]
        stairType = ['SDB', 'SDL', 'SDT', 'SDR']

        return getStair(stairs, stairType, 'SDD')

    def getDDStair(mapfile, yPos, xPos):
        mapPart = getCoordinates(mapfile, yPos, xPos)
        stairs = [mapPart['N'], mapPart['E'], mapPart['S'], mapPart['W']]
        stairType = ['SDDT', 'SDDR', 'SDDB', 'SDDL']

        return getStair(stairs, stairType, 'SD')

    funcSymbols = {
        '':     getWall,
        'SU':   getUStair,
        'SUU':  getUUStair,
        'SD':   getDStair,
        'SDD':  getDDStair
    }

    parsedList = []
    for row, col in enumerate(arrMap):
        rowList = []
        for col, tile in enumerate(col):
            if tile in funcSymbols:
                rowList.append(funcSymbols[tile](arrMap, row, col))
            else:
                rowList.append(txtSymbols[tile])
        parsedList.append(rowList)
    return parsedList



#!/usr/bin/env python

import setuptools

with open("README.rst", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='donjon-painter',
    version='0.9.5',
    author='Korvin Roganov',
    author_email='korvinagor@vivaldi.net',
    license='GPLv3',
    description='Graphical map translator for donjon\'s Random Dungeon Generator TSV files.',
    long_description=long_description,
    url='https://github.com/donjon-painter/donjon-painter',
    packages=setuptools.find_packages(),
    include_package_data=True,
    package_dir={'donjon-painter': 'donjon_painter'},
    entry_points={
        'console_scripts': [
            'donjon-painter = donjon_painter.painter:main'
        ]
    },
    python_requires='>=3.5',
    install_requires=[
        'Pillow'
    ],
    classifiers=[
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Topic :: Utilities",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent"
    ])
